==> eslint-plugin-angular-0.2.2.tgz: package/test/ng_controller_name.js <==
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var eslint = require('../node_modules/eslint/lib/eslint'),
    ESLintTester = require('eslint-tester');

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var eslintTester = new ESLintTester(eslint);
eslintTester.addRuleTest('rules/ng_controller_name', {
    valid: [{
        code: 'app.controller("eslintController", function(){});',
        args: [1, 'eslint']
    }, {
        code: 'app.controller("eslintController", function(){});',
        args: [1, /^eslint/]
    }, {
        code: 'app.controller("eslintController", function(){});',
        args: [1, undefined]
    }, {
        code: 'app.controller("EslintController", function(){});',
        args: [1, /[A-Z].*Controller$/]
    }, {
        code: 'app.controller("EslintController", function(){});',
        args: [1, '/[A-Z].*Controller$/']
    }, {
        code: 'controller = el.controller();',
        args: [1, '/[A-Z].*Controller$/']
    }],
    invalid: [
        {
            code: 'app.controller("Controller", function(){});',
            args: [1, 'eslint'],
            errors: [{ message: 'The Controller controller should be prefixed by eslint'}]
        },
        {
            code: 'app.controller("esLintController", function(){});',
            args: [1, 'eslint'],
            errors: [{ message: 'The esLintController controller should be prefixed by eslint'}]
        },
        {
            code: 'app.controller("Controller", function(){});',
            args: [1, /^eslint/],
            errors: [{ message: 'The Controller controller should follow this pattern: /^eslint/'}]
        },
        {
            code: 'app.controller("customers", function(){});',
            args: [1, /[A-Z].*Controller$/],
            errors: [{ message: 'The customers controller should follow this pattern: /[A-Z].*Controller$/'}]
        },
        {
            code: 'app.controller("customersController", function(){});',
            args: [1, /[A-Z].*Controller$/],
            errors: [{ message: 'The customersController controller should follow this pattern: /[A-Z].*Controller$/'}]
        }, {
            code: 'app.controller("eslintController", function(){});',
            args: [1, '/[A-Z].*Controller$/'],
            errors: [{ message: 'The eslintController controller should follow this pattern: /[A-Z].*Controller$/'}]
        }
    ]
});

==> eslint-plugin-angular-0.5.0.tgz: package/test/ng_controller_name.js <==
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var rule = require('../rules/ng_controller_name'),
    RuleTester = require("eslint").RuleTester;

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var eslintTester = new RuleTester();
eslintTester.run('ng_controller_name', rule, {
    valid: [{
        code: 'app.controller("eslintController", function(){});',
        options: ['eslint']
    }, {
        code: 'app.controller("eslintController", function(){});',
        options: [/^eslint/]
    }, {
        code: 'app.controller("eslintController", function(){});',
        options: [undefined]
    }, {
        code: 'app.controller("EslintController", function(){});',
        options: [/[A-Z].*Controller$/]
    }, {
        code: 'app.controller("EslintController", function(){});',
        options: ['/[A-Z].*Controller$/']
    }, {
        code: 'controller = el.controller();',
        options: ['/[A-Z].*Controller$/']
    }],
    invalid: [
        {
            code: 'app.controller("Controller", function(){});',
            options: ['eslint'],
            errors: [{ message: 'The Controller controller should be prefixed by eslint'}]
        },
        {
            code: 'app.controller("esLintController", function(){});',
            options: ['eslint'],
            errors: [{ message: 'The esLintController controller should be prefixed by eslint'}]
        },
        {
            code: 'app.controller("Controller", function(){});',
            options: [/^eslint/],
            errors: [{ message: 'The Controller controller should follow this pattern: /^eslint/'}]
        },
        {
            code: 'app.controller("customers", function(){});',
            options: [/[A-Z].*Controller$/],
            errors: [{ message: 'The customers controller should follow this pattern: /[A-Z].*Controller$/'}]
        },
        {
            code: 'app.controller("customersController", function(){});',
            options: [/[A-Z].*Controller$/],
            errors: [{ message: 'The customersController controller should follow this pattern: /[A-Z].*Controller$/'}]
        }, {
            code: 'app.controller("eslintController", function(){});',
            options: ['/[A-Z].*Controller$/'],
            errors: [{ message: 'The eslintController controller should follow this pattern: /[A-Z].*Controller$/'}]
        }
    ]
});
